(configuration)=
# Configuration

(configuration-models)=
## Configuration models

```{eval-rst}
.. autopydantic_settings:: r2x.config_models.BaseModelConfig
   :settings-show-json: False
   :settings-show-config-summary: False
   :settings-show-validator-members: False
   :settings-show-validator-summary: False
   :field-list-validators: False
```

```{eval-rst}
.. autopydantic_settings:: r2x.config_models.InfrasysConfig
   :settings-show-json: False
   :settings-show-config-summary: False
   :settings-show-validator-members: False
   :settings-show-validator-summary: False
   :field-list-validators: False
```

```{eval-rst}
.. autopydantic_settings:: r2x.config_models.ReEDSConfig
   :settings-show-json: False
   :settings-show-config-summary: False
   :settings-show-validator-members: False
   :settings-show-validator-summary: False
   :field-list-validators: False
```

```{eval-rst}
.. autopydantic_settings:: r2x.config_models.PlexosConfig
   :settings-show-json: False
   :settings-show-config-summary: False
   :settings-show-validator-members: False
   :settings-show-validator-summary: False
   :field-list-validators: False
```

```{eval-rst}
.. autopydantic_settings:: r2x.config_models.SiennaConfig
   :settings-show-json: False
   :settings-show-config-summary: False
   :settings-show-validator-members: False
   :settings-show-validator-summary: False
   :field-list-validators: False
```

(scenario-models)=
## Scenario models
```{eval-rst}
.. automodule:: r2x.config_scenario
    :members:
```
